@@ -3,8 +3,6 @@ package DBIx::Class::Migration::Script;
 use Moose;
 use MooseX::Attribute::ENV;
 use MooseX::Types::LoadableClass 'LoadableClass';
-use Pod::Find ();
-use Pod::Usage ();
 
 with 'MooseX::Getopt';
 
@@ -24,15 +22,15 @@ has includes => (
   is => 'ro',
   isa => 'ArrayRef',
   predicate => 'has_includes',
-  cmd_aliases => ['include','I', 'lib','libs']);
+  cmd_aliases => ['I', 'libs']);
 
 has schema => (is=>'ro', predicate=>'has_schema');
 
 has schema_class => (traits => [ 'Getopt', 'ENV' ], is => 'ro', isa => 'Str',
   predicate=>'has_schema_class', env_prefix=>ENV_PREFIX, cmd_aliases => 'S');
 
-has target_dir => (traits => [ 'Getopt', 'ENV' ], is => 'ro', isa=> 'Str',
-  predicate=>'has_target_dir', env_prefix=>ENV_PREFIX, cmd_aliases => 'dir');
+has target_dir => (traits => [ 'Getopt' ], is => 'ro', isa=> 'Str',
+  predicate=>'has_target_dir', cmd_aliases => 'dir');
 
 has username => (traits => [ 'Getopt', 'ENV' ], is => 'ro', isa => 'Str',
   default => '', env_prefix=>ENV_PREFIX, cmd_aliases => 'U');
@@ -49,14 +47,11 @@ has force_overwrite => (traits => [ 'Getopt' ], is => 'ro', isa => 'Bool',
 has to_version => (traits => [ 'Getopt' ], is => 'ro', isa => 'Int',
   predicate=>'has_to_version', cmd_aliases => 'V');
 
-has sql_translator_args => (traits => [ 'Getopt' ], is => 'ro', isa => 'HashRef',
-  predicate=>'has_sql_translator_args');
-
 has databases => (traits => [ 'Getopt' ], is => 'ro', isa => 'ArrayRef',
   predicate=>'has_databases', cmd_aliases => 'database');
 
-has sandbox_class => (traits => [ 'Getopt', 'ENV' ], is => 'ro', isa => 'Str',
-  predicate=>'has_sandbox_class', default=>SANDBOX_SQLITE,
+has sandbox_class =>  (traits => [ 'Getopt', 'ENV' ], is => 'ro', isa => 'Str',
+  predicate=>'has_sandbox_class', default=>SANDBOX_SQLITE, 
   cmd_aliases => ['T','sb'], env_prefix=>ENV_PREFIX);
 
 has dbic_fixture_class => (traits => [ 'Getopt' ], is => 'ro', isa => 'Str',
@@ -65,15 +60,6 @@ has dbic_fixture_class => (traits => [ 'Getopt' ], is => 'ro', isa => 'Str',
 has dbic_fixtures_extra_args => (traits => [ 'Getopt' ], is => 'ro', isa => 'HashRef',
   predicate=>'has_dbic_fixtures_extra_args');
 
-has dbic_connect_attrs => (traits => [ 'Getopt' ], is => 'ro', isa => 'HashRef',
-  predicate=>'has_dbic_connect_attrs');
-
-has dbi_connect_attrs => (traits => [ 'Getopt' ], is => 'ro', isa => 'HashRef',
-  predicate=>'has_dbi_connect_attrs');
-
-has extra_schemaloader_args => (traits => [ 'Getopt' ], is => 'ro', isa => 'HashRef',
-  predicate=>'has_extra_schemaloader_args');
-
 has fixture_sets => (
   traits => [ 'Getopt' ],
   is=>'ro',
@@ -86,7 +72,7 @@ has fixture_sets => (
       version status prepare install upgrade
       downgrade drop_tables delete_table_rows
       dump_all_sets make_schema install_if_needed
-      dump diagram install_version_storage );
+      dump );
   }
 
 has migration_class => (
@@ -96,9 +82,6 @@ has migration_class => (
   isa => LoadableClass,
   coerce => 1);
 
-has migration_sandbox_builder_class => (traits => [ 'Getopt' ],
-  is => 'ro', isa => 'Str', predicate=>'has_migration_sandbox_builder_class');
-
 has migration => (
   is => 'ro',
   lazy_build => 1,
@@ -110,14 +93,6 @@ has migration => (
     if($self->dsn) {
       push @schema_args, ($self->dsn,
        $self->username, $self->password);
-    
-      if($self->has_dbi_connect_attrs) {
-        push @schema_args, $self->dbi_connect_attrs;
-      }
-      if($self->has_dbic_connect_attrs) {
-        push @schema_args, {} unless $self->has_dbi_connect_attrs;
-        push @schema_args, $self->dbic_connect_attrs;
-      }
     }
     return @schema_args;
   }
@@ -126,10 +101,9 @@ has migration => (
     my $self = shift;
     return (
       ($self->has_force_overwrite ? (force_overwrite => $self->force_overwrite) : ()),
-      ($self->has_target_dir && $self->target_dir ? (script_directory=>$self->target_dir) : ()),
+      ($self->has_target_dir ? (script_directory=>$self->target_dir) : ()),
       ($self->has_to_version ? (to_version=>$self->to_version) : ()),
       ($self->has_databases ? (databases=>$self->databases) : ()),
-      ($self->has_sql_translator_args ? (sql_translator_args=>$self->sql_translator_args) : ()),
     );
   }
 
@@ -140,15 +114,12 @@ sub _build_migration {
 
   if($self->has_schema) {
     $args{schema} = $self->schema;
-  } elsif($self->has_schema_class && $self->schema_class) {
+  } else {
     my @schema_args = $self->_prepare_schema_args;
     $args{schema_class} = $self->schema_class;
     $args{schema_args} = \@schema_args if @schema_args;
   }
 
-  $args{target_dir} = $self->target_dir
-    if $self->has_target_dir && $self->target_dir;
-
   if($self->has_sandbox_class) {
     my ($plus, $class) = ($self->sandbox_class=~/^(\+)*(.+)$/);
     $args{db_sandbox_class} = $plus ? $class : "DBIx::Class::Migration::$class";
@@ -160,14 +131,6 @@ sub _build_migration {
   $args{dbic_fixtures_extra_args} = $self->dbic_fixtures_extra_args
     if $self->has_dbic_fixtures_extra_args;
 
-  $args{extra_schemaloader_args} = $self->extra_schemaloader_args
-    if $self->has_extra_schemaloader_args;
-
-  if($self->has_migration_sandbox_builder_class) {
-    my ($plus, $class) = ($self->migration_sandbox_builder_class=~/^(\+)*(.+)$/);
-    $args{db_sandbox_builder_class} = $plus ? $class : "DBIx::Class::Migration::$class";
-  }
-
   return $self->migration_class->new(%args);
 }
 
@@ -177,27 +140,12 @@ sub cmd_dump_named_sets {
     ->dump_named_sets(@{$self->fixture_sets});
 }
 
-sub cmd_delete_named_sets {
-  my $self = shift;
-  $self->migration
-    ->delete_named_sets(@{$self->fixture_sets});
-}
-
 sub cmd_populate {
   my $self = shift;
   $self->migration
     ->populate(@{$self->fixture_sets});
 }
 
-sub cmd_help {
-  my ($self, $subhelp) = @_;
-  my $docs = "DBIx::Class::Migration::Script::Help" . ($subhelp ? "::$subhelp" : "");
-  Pod::Usage::pod2usage(
-    -verbose => 2,
-    -exitval => 'NOEXIT',
-    -input => Pod::Find::pod_where({-inc => 1}, $docs));
-}
-
 sub _import_libs {
   my ($self, @libs) = @_;
   require lib;
@@ -211,21 +159,16 @@ sub _defaults {
 
 sub run {
   my ($self) = @_;
-  my ($argv, @extra_argv) = @{$self->extra_argv};
+  my ($cmd, @extra_argv) = @{$self->extra_argv};
 
   $self->_import_libs(@{$self->includes})
     if $self->has_includes;
 
-  if(!$argv || $argv eq 'help') {
-    $self->cmd_help(@extra_argv);
-  } else {
-    foreach my $cmd ($argv, @extra_argv) {
-      $self->can("cmd_${cmd}") ?
-        $self->${\"cmd_${cmd}"} :
-        die "No such command ${cmd}\n";
-    }
+  die "Must supply a command\n" unless $cmd;
+  die "Extra argv detected - command only please\n" if @extra_argv;
+  die "No such command ${cmd}\n" unless $self->can("cmd_${cmd}");
 
-  }
+  $self->${\"cmd_${cmd}"};
 }
 
 sub run_with_options {
@@ -234,11 +177,6 @@ sub run_with_options {
     ->run;
 }
 
-sub new_with_defaults {
-  my $class = shift;
-  return $class->new_with_options($class->_defaults, @_);
-}
-
 sub run_if_script {
   my $class = shift;
   caller(1) ? $class : $class->run_with_options(@_);
@@ -254,9 +192,9 @@ DBIx::Class::Migration::Script - Tools to manage database Migrations
 =head1 SYNOPSIS
 
     dbic-migration status \
-      --lib="lib" \
+      --libs="lib" \
       --schema_class='MyApp::Schema' \
-      --dsn='DBI:SQLite:myapp.db'
+      --dns='DBI:SQLite:myapp.db'
 
 =head1 DESCRIPTION
 
@@ -350,8 +288,8 @@ Accepts Str.  Not Required
 This is the DSN for the database you are going to be targeting for deploying
 or altering ddl, and installing or generating fixtures.
 
-This should be a DSN suitable for L<DBIx::Class::Schema/connect>, something
-in the form of C<DBI:SQLite:myapp-schema.db>.
+This should be a DSN suitable for L<DBIx::Class::Schema/connect), something
+in the form of C<DBI:SQLite:myapp-schema.db)>.
 
 Please take care where you point this (like production :) )
 
@@ -409,18 +347,6 @@ L<SQLT>.  If you leave this undefined we will derive a value based on the value
 of L</dsn>.  For example, if your L</dsn> is "DBI:SQLite:test.db", we will set
 the valuye of L</databases> to C<['SQLite']>.
 
-=head2 sql_translator_args
-
-Accepts HashRef.  Not Required.
-
-Used when building L</migration> to set the L<DBIx::Class::DeploymentHandler>
-option C<sql_translator_args>. This can be used to specify options for
-L<SQL::Translator>, for example:
-
-    producer_args => { postgres_version => '9.1' }
-
-to define the database version for SQL producer.
-
 =head2 fixture_sets
 
 Accepts ArrayRef.  Not Required. Defaults to ['all_tables'].
@@ -446,7 +372,7 @@ computer (and if not it is trivial to install).
 You can change this to either 'PostgresqlSandbox' or 'MySQLSandbox', which will
 create a sandbox using either L<DBIx::Class::Migration::MySQLSandbox> or 
 L<DBIx::Class::Migration::PostgresqlSandbox> (which in term require the separate
-installation of either L<Test::mysqld> or L<Test::PostgreSQL>).  If you are
+installation of either L<Test::mysqld> or L<Test::postgresql>).  If you are
 using one of those open source databases in production, its probably a good
 idea to use them in development as well, since there are enough small
 differences between them that could make your code break if you used sqlite for
@@ -454,7 +380,7 @@ development and postgresql in production.  However this requires a bit more
 setup effort, so when you are starting off just sticking to the default sqlite
 is probably the easiest thing to do.
 
-You should review the documenation at L<DBIx::Class::Migration::MySQLSandbox> or 
+YOu should review the documenation at L<DBIx::Class::Migration::MySQLSandbox> or 
 L<DBIx::Class::Migration::PostgresqlSandbox> because those delegates also build
 some helper scripts, intended to help you use a sandbox.
 
@@ -463,7 +389,7 @@ DBIC_MIGRATION_SANDBOX_CLASS
 
 If you need to create your own custom database sandboxes, please see:
 L<DBIx::Class::Migration::Sandbox> which is the role your sandbox factory needs
-to complete.  You can signify your custom sandbox by using the full package name
+tp complete.  You can signify your custom sandbox by using the full package name
 with a '+' prepended.  For example:
 
     sandbox_class => '+MyApp::Schema::CustomSandbox'
@@ -479,7 +405,7 @@ Should point to the class that does what L<DBIx::Class::Migration> does.  This
 is exposed here for those who need to subclass L<DBIx::Class::Migration>.  We
 don't expose this attribute to the commandline, so if you are smart enough to
 do the subclassing (and sure you need to do that), I will assume you will also
-either subclass L<DBIx::Class::Migration:Script> or override then default
+either subclass L<L<DBIx::Class::Migration:Script> or override then default
 value using some standard technique.
 
 =head2 dbic_fixture_class
@@ -496,45 +422,9 @@ If provided will add some additional arguments when creating an instance of
 L</dbic_fixture_class>.  You should take a look at the documentation for
 L<DBIx::Class::Fixtures> to understand what additional arguments may be of use.
 
-=head2 dbi_connect_attrs
-
-Accepts: HashRef, Not Required.
-
-If you are specifying a DSN, you might need to provide some additional args
-to L<DBI> (see L<DBIx::Class::Storage::DBI/connect_info> for more).
-
-=head2 dbic_connect_attrs
-
-Accepts: HashRef, Not Required.
-
-If you are specifying a DSN, you might need to provide some additional args
-to L<DBIx::Class> (see L<DBIx::Class::Storage::DBI/connect_info> for more).
-
-You can also see L<DBIx::Class::Storage::DBI/DBIx::Class-specific-connection-attributes>
-for more information on what this can do for you.  Chances are good if you
-need this you will also want to subclass L<DBIx::Class::Migration::Script> as
-well.
-
-Common uses for this is to run SQL on startup and set Postgresql search paths.
-
-=head2 extra_schemaloader_args
-
-Accepts: HashRef, Not Required.
-
-Used to populate L<DBIx::Class::Migration/extra_schemaloader_args>
-
-=head2 migration_sandbox_builder_class
-
-Accepts: String (Classname), Not Required.
-
-Used to set L<DBIx::Class::Migration/db_sandbox_builder_class>.  You probably
-won't mess with this unless you are writing your own Sandbox builder class, or
-using the alternative builder L<DBIx::Class::Migration::TempDirSandboxBuilder>
-for creating temporary sandboxes when you want to test your migrations.
-
 =head1 COMMANDS
 
-    dbic-migration -Ilib install
+    dbic_migration -Ilib install
 
 Since this class consumes the L<MooseX::GetOpt> role, it can be run directly
 as a commandline application.  The following is a list of commands we support
@@ -542,71 +432,80 @@ as well as the options / flags associated with each command.
 
 =head2 help
 
-See L<DBIx::Class::Migration::Script::Help::help>.
+Summary of commands and aliases.
 
 =head2 version
 
-See L<DBIx::Class::Migration::Script::Help::version>.
+prints the current version of the application to STDOUT
 
 =head2 status
 
-See L<DBIx::Class::Migration::Script::Help::status>.
+Returns the state of the deployed database (if it is deployed) and the state
+of the current C<schema>
 
 =head2 prepare
 
-See L<DBIx::Class::Migration::Script::Help::prepare>.
+Creates a C<fixtures> and C<migrations> directory under L</target_dir> (if they
+don't already exist) and makes deployment files for the current schema.  If
+deployment files exist, will fail unless you L</overwrite_migrations> and
+L</overwrite_fixtures>.
 
 =head2 install
 
-See L<DBIx::Class::Migration::Script::Help::install>.
+Installs either the current schema version (if already prepared) or the target
+version specified via L</to_version> to the database connected via the L</dsn>,
+L</username> and L</password>
 
 =head2 upgrade
 
-See L<DBIx::Class::Migration::Script::Help::upgrade>.
+Run upgrade files to either bring the database into sync with the current
+schema version, or stop at an intermediate version specified via L</to_version>
 
 =head2 downgrade
 
-See L<DBIx::Class::Migration::Script::Help::downgrade>.
+Run down files to bring the database down to the version specified via
+L</to_version>
 
 =head2 dump_named_sets
 
-See L<DBIx::Class::Migration::Script::Help::dump_named_sets>.
+Given listed L<fixture_sets>, dump files for the current database version (not
+the current schema version)
 
 =head2 dump_all_sets
 
-See L<DBIx::Class::Migration::Script::Help::dump_all_sets>.
+Just dump all the sets for the current database
 
 =head2 populate
 
-See L<DBIx::Class::Migration::Script::Help::populate>.
+Given listed L<fixture_sets>, populate a database with fixtures for the matching
+version (matches database version to fixtures, not the schema version)
 
 =head2 drop_tables
 
-See L<DBIx::Class::Migration::Script::Help::drop_tables>.
+Drops all the tables in the connected database with no backup or recovery.  For
+real! (Make sure you are not connected to Prod, for example)
 
 =head2 delete_table_rows
 
-See L<DBIx::Class::Migration::Script::Help::delete_table_rows>.
+does a C<delete> on each table in the database, which clears out all your data
+but preserves tables.  For Real!  You might want this if you need to load
+and unload fixture sets during testing, or perhaps to get rid of data that
+accumulated in the database while running an app in development, before dumping
+fixtures.
+
+Skips the table C<dbix_class_deploymenthandler_versions>, so you don't lose
+deployment info (this is different from L</drop_tables> which does delete it.)
 
 =head2 make_schema
 
-See L<DBIx::Class::Migration::Script::Help::make_schema>.
+Creates DBIC schema files from the currently deployed database into your target
+directory.  You can use this to bootstrap your ORM, or if you get confused about
+what the deployment perl run files get for schema.
 
 =head2 install_if_needed
 
-See L<DBIx::Class::Migration::Script::Help::install_if_needed>.
-
-=head2 install_version_storage
-
-See L<DBIx::Class::Migration::Script::Help::install_version_storage>.
-
-=head2 diagram
-
-See L<DBIx::Class::Migration::Script::Help::diagram>.
-
-=head2 delete_named_sets
-
-See L<DBIx::Class::Migration::Script::Help::delete_named_sets>.
+Install the database to the current C<$schema> version if it is not currently
+installed.  Otherwise this is a nop (even if the database is behind the schema).
 
 =head2 Command Flags
 
@@ -614,15 +513,40 @@ The following flags are used to modify or inform commands.
 
 =head3 includes
 
-See L<DBIx::Class::Migration::Script::Help::includes>.
+Aliases: I, lib
+Value: String or Array of Strings
+
+    dbic_migration --includes lib --includes /opt/perl/lib
+
+Does the same thing as the Perl command line interpreter flag C<I>.  Adds all
+the listed paths to C<@INC>.  You will likely use this in order to find your
+application schema (subclass of L<DBIx::Class::Schema>.
 
 =head3 schema_class
 
-See L<DBIx::Class::Migration::Script::Help::schema_class>.
+Value: Str
+
+    dbic_migration prepare --schema_class MyApp::Schema -Ilib
+
+Used to specify the L<DBIx::Class::Schema> subclass which is the core of your
+L<DBIx::Class> based ORM managed system.  This is required and the application
+cannot function without one.
 
 =head3 target_dir
 
-See L<DBIx::Class::Migration::Script::Help::target_dir>.
+Aliases: D
+Value: Str
+
+    dbic_migration prepare --schema_class MyApp::Schema --target_dir /opt/share
+
+We need a directory path that is used to store your fixtures and migration
+files.  By default this will be the C<share> directory for the application
+where your L</schema_class> resides.  I recommend you leave it alone since
+this is a reasonable Perl convention for non code data, and there's a decent
+ecosystem of tools around it, however if you need to place the files in an
+alternative location (for example you have huge fixture sets and you don't
+want them in you core repository, or you can't store them in a limited space
+filesystem) this will let you do it.  Option and defaults as discussed.
 
 =head3 username
 
@@ -643,27 +567,101 @@ database, where we will deploy migrations and fixtures.  If you don't provide
 them, we will automatically deploy to a L<DBD::SQLite> managed database located
 at L</target_dir>.
 
-    dbic-migration install --username myuser --password mypass --dsn DBI:SQLite:mydb.db
+    dbic_migration install --username myuser --password mypass --dsn DBI:SQLite:mydb.db
 
 =head3 force_overwrite
 
-See L<DBIx::Class::Migration::Script::Help::force_overwrite>
+Aliases: O
+Value: Bool (default: False)
+
+Sometimes you may wish to prepare migrations for the same version more than
+once (say if you are developing a new version and need to try out a few options
+first).  This lets you deploy over an existing set.  This will of course destroy
+and manual modifications you made, buyer beware.)
+
+    dbic_migration prepare --overwrite_migrations
 
 =head3 to_version
 
-See L<DBIx::Class::Migration::Script::Help::to_version>
+Aliases: D
+Value: Str (default: Current VERSION of Schema)
+
+    dbic_migration install --to_version 5
+
+Used to specify which version we are going to deploy.  Defaults to whatever
+is the most current version you've prepared.
+
+Use this when you need to force install an older version, such as when you are
+roundtripping prepares while fiddling with a new database version.
 
 =head3 databases
 
-See L<DBIx::Class::Migration::Script::Help::databases>
+Alias: database
+Value: Str or Array of Str (default: SQLite)
+
+You can prepare deployment for any database type that L<SQLT> understand.  By
+default we only prepare a deployment version for the database which matches
+the L<dsn> you specified but you can use this to prepare additional deployments
+
+    dbic_migration prepare --database SQLite --database mysql
+
+Please note if you choose to manually set this value, you won't automatically
+get the default, unless you specify as above
 
 =head3 fixture_sets
 
-See L<DBIx::Class::Migration::Script::Help::fixture_sets>
+Alias: fixture_set
+Value: Str or Array of Str (default: all set)
+
+When dumping or populating fixture sets, you use this to set which sets.
+
+    dbic_migration dump --fixture_set roles --fixture_set core
+
+Please note that if you manually describe your sets as in the above example,
+you don't automatically get the C<all_tables> set, which is a fixture set of all
+database information and not 'all' the sets.
+
+We automatically create the C<all_tables> fixture set description file for you when
+you prepare a new migration of the schema.  You can use this set for early
+testing but I recommend you study L<DBIx::Class::Fixtures> and learn the set
+configuration rules, and create limited fixture sets for given purposes, rather
+than just dump / populate everything, since that is like to get big pretty fast
+
+My recommendation is to create a core 'seed' set, of default database values,
+such as role types, default users, lists of countries, etc. and then create a
+'demo' or 'dev' set that contains extra information useful to populate a
+database so that you can run test cases and develop against.
 
 =head3 sandbox_class
 
-See L<DBIx::Class::Migration::Script::Help::sandbox_class>
+Alias: T
+Value: String (default: SqliteSandbox)
+
+If you don't have a target database for your migrations (as you might not for
+your development setup, or during initial prototyping) we automatically create
+a local database sandbox in your L</target_dir>.  By default this is a
+L<DBD::Sqlite> single file database, since this is easy to get installed (you
+probably already have it) and is easy to work with.  However, we can also create
+database sandboxes for mysql and postgresql (although you will need to get the
+L<Test::mysqld> and/or L<Test::postgresql> as well as the correcct DBD installed).
+
+This is handy as you move toward a real production target and know the eventual
+database for production.  If you choose to create a postgresql or mysql database
+sandbox, they will automatically be created in your L</target_dir>, along with
+some helper scripts. See L<DBIx::Class::Migration::PostgresqlSandbox> and
+L<DBIx::Class::Migration::MySQLSandbox> for more documentation.
+
+Assuming you've prepared migrations for an alternative sandbox, such as MySQL:
+
+    dbic_migration install --schema_class MyApp::Schema --sandbox_class MySQLSandbox
+
+Would install it.  Like some of the other option flags you can specify with an
+%ENV setting:
+
+    export DBIC_MIGRATION_SANDBOX_CLASS=MySQLSandbox
+
+This would be handy if you are always going to target one of the alternative
+sandbox types.
 
 The default sqlite sandbox is documented at L<DBIx::Class::Migration::SQLiteSandbox>
 although this single file database is pretty straightforward to use.
@@ -671,26 +669,6 @@ although this single file database is pretty straightforward to use.
 If you are declaring the value in a subclass, you can use the pre-defined
 constants to avoid typos (see L</CONSTANTS>).
 
-=head3 dbic_fixture_class
-
-See L<DBIx::Class::Migration::Script::Help::dbic_fixture_class>
-
-=head3 dbic_fixtures_extra_args
-
-See L<DBIx::Class::Migration::Script::Help::dbic_fixtures_extra_args>
-
-=head3 dbic_connect_attrs
-
-See L<DBIx::Class::Migration::Script::Help::dbic_connect_attrs>
-
-=head3 dbi_connect_attrs
-
-See L<DBIx::Class::Migration::Script::Help::dbi_connect_attrs>
-
-=head3 extra_schemaloader_args
-
-See L<DBIx::Class::Migration::Script::Help::extra_schemaloader_args>
-
 =head1 OPTIONAL METHODS FOR SUBCLASSES
 
 If you decide to make a custom subclass of L<DBIx::Class::Migration::Script>,
@@ -771,32 +749,32 @@ PostgresqlSandbox
 Please see L<DBIx::Class::Migration::Tutorial> for more.  Here's some basic use
 cases.
 
-=head2 Prepare deployment files for a schema
+head2 Prepare deployment files for a schema
 
-    dbic-migration prepare --schema_class MyApp::Schema
+    dbic_migration prepare --schema_class MyApp::Schema
 
 This will prepare deployment files for just SQLite
 
-    dbic-migration prepare --database SQLite --database MySQL \
+    dbic_migration prepare --database SQLite --database mysql \
       --schema_class MyApp::Schema
 
 This will prepare deployment files for both SQLite and MySQL
 
-=head2 Install database from deployments
+head2 Install database from deployments
 
-    dbic-migration install --schema_class MyApp::Schema
+    dbic_migration install --schema_class MyApp::Schema
 
 Creates the default sqlite database in the C<share> directory.
 
-    dbic-migration install --schema_class MyApp::Schema --to_version 2
+    dbic_migration install --schema_class MyApp::Schema --to_version 2
 
 Same as the previous command, but installs version 2, instead of whatever is
 the most recent version
 
-    dbic-migration populate --schema_class MyApp::Schema --fixture_set seed
+    dbic_migration populate --schema_class MyApp::Schema --fixture_set seed
 
 Populates the C<seed> fixture set to the current database (matches the database
-version to the seed version.)
+version to the seed version.
 
 =head1 SEE ALSO
 
